@@ -4,11 +4,11 @@
  * Gnome Crystal
  * celldlg.h
  *
- * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -27,16 +27,32 @@
 
 #include <gcugtk/dialog.h>
 
+/*!\file*/
+
 namespace gcr {
 
 class Document;
 class Application;
 
+/*!\class CellDlg gcr/celldlg.h
+\brief GCrystal cell dialog class.
+
+This class wraps the dialog used to define the crystal cell.
+*/
 class CellDlg: public gcugtk::Dialog
 {
 friend class CellDlgPrivate;
 public:
+/*!
+@param App the application running the dialog.
+@param pDoc the document.
+
+Creates the dialog.
+*/
 	CellDlg (Application *App, Document* pDoc);
+/*!
+The destructor.
+*/
 	virtual ~CellDlg ();
 
 private:
